@@ -1,6 +1,6 @@
 from pydantic import BaseModel, Field, root_validator
 from caseconverter import camelcase #type: ignore
-from typing import Any, Optional, Dict
+from typing import Any, Dict
 import typing
 # import deeplabel.client
 
@@ -15,7 +15,7 @@ class MixinConfig(BaseModel):
 
 class DeeplabelBase(MixinConfig):
     """Base Model for all models that don't need client"""
-    extra:Optional[Dict[str, Any]] = Field(exclude=True, default=dict)
+    extra:Dict[str, Any] = Field(exclude=True, default=dict)
     client: Any = Field(default=None, exclude=True)
 
     @root_validator(pre=True)
