@@ -1,6 +1,6 @@
 import dataclasses  # type: ignore
 from dataclasses import InitVar
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Union
 import inspect
 import requests
 from requests.adapters import HTTPAdapter
@@ -30,7 +30,7 @@ class BaseClient:
     infer_url: str = "https://deeplabel.app/videolabel/infer"
     # session: Any = Field()
     project_id: Optional[str] = None
-    restriction: str = "true"
+    restriction: Union[bool, str] = True
 
     def __post_init__(self):
         session = requests.Session()
